@@ -220,6 +220,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._session.headers['X-Auth-Token'] = 'asdf1234'
         expected_headers = self.headers.copy()
         expected_headers['OData-Version'] = '4.0'
+        expected_headers['Content-Type'] = 'application/json'
         self.conn._op('POST', path='fake/path', headers=self.headers,
                       data=self.data)
         self.request.assert_called_once_with(
@@ -317,7 +318,23 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertIsNotNone(exc.body)
         self.assertIn('body submitted was malformed JSON', exc.detail)
 
-    def test_not_found_error(self):
+    def test_known_http_error_nonlist_ext_info(self):
+        self.request.return_value.status_code =\
+            http_client.UNSUPPORTED_MEDIA_TYPE
+        with open('sushy/tests/unit/json_samples/'
+                  'error_single_ext_info.json') as f:
+            self.request.return_value.json.return_value = json.load(f)
+
+        with self.assertRaisesRegex(exceptions.HTTPError,
+                                    'See Resolution for information') as cm:
+            self.conn._op('POST', 'http://foo.bar')
+        exc = cm.exception
+        self.assertEqual(http_client.UNSUPPORTED_MEDIA_TYPE, exc.status_code)
+        self.assertIsNotNone(exc.body)
+        self.assertIn('See Resolution for information', exc.detail)
+
+    @mock.patch('time.sleep', autospec=True)
+    def test_not_found_error(self, mock_sleep):
         self.request.return_value.status_code = http_client.NOT_FOUND
         self.request.return_value.json.side_effect = ValueError('no json')
 
@@ -326,8 +343,11 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.NOT_FOUND, exc.status_code)
+        self.assertFalse(mock_sleep.called)
+        self.assertEqual(1, self.request.call_count)
 
-    def test_server_error(self):
+    @mock.patch('time.sleep', autospec=True)
+    def test_server_error(self, mock_sleep):
         self.request.return_value.status_code = (
             http_client.INTERNAL_SERVER_ERROR)
         self.request.return_value.json.side_effect = ValueError('no json')
@@ -337,6 +357,8 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.INTERNAL_SERVER_ERROR, exc.status_code)
+        self.assertEqual(5, mock_sleep.call_count)
+        self.assertEqual(6, self.request.call_count)
 
     def test_access_error(self):
         self.conn._auth.can_refresh_session.return_value = False
@@ -350,6 +372,25 @@ class ConnectorOpTestCase(base.TestCase):
         exc = cm.exception
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
 
+    @mock.patch.object(connector.LOG, 'debug', autospec=True)
+    def test_access_error_service_session(self, mock_log):
+        self.conn._auth.can_refresh_session.return_value = False
+
+        self.request.return_value.status_code = http_client.FORBIDDEN
+        self.request.return_value.json.side_effect = ValueError('no json')
+
+        with self.assertRaisesRegex(exceptions.AccessError,
+                                    'unknown error') as cm:
+            self.conn._op('GET', 'http://redfish/v1/SessionService')
+        exc = cm.exception
+        mock_log.assert_called_with(
+            'HTTP GET of SessionService failed %s, '
+            'this is expected prior to authentication', 'HTTP GET '
+            'http://redfish/v1/SessionService returned code '
+            '%s. unknown error Extended information: '
+            'none' % http_client.FORBIDDEN)
+        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
+
     def test_blocking_no_location_header(self):
         self.request.return_value.status_code = http_client.ACCEPTED
         self.request.return_value.headers = {'retry-after': 5}
@@ -362,9 +403,11 @@ class ConnectorOpTestCase(base.TestCase):
         response1 = mock.MagicMock(spec=requests.Response)
         response1.status_code = http_client.ACCEPTED
         response1.headers = {
-            'retry-after': 5,
-            'location': '/redfish/v1/taskmon/1'
+            'Retry-After': 5,
+            'Location': '/redfish/v1/taskmon/1',
+            'Content-Length': 10
         }
+        response1.json.return_value = {'Id': 3, 'Name': 'Test'}
         response2 = mock.MagicMock(spec=requests.Response)
         response2.status_code = http_client.BAD_REQUEST
         message = 'Unable to create Volume with given parameters'
